| Popover.triggerId | R Documentation |
Custom Popover bound to a DOM element by id. See 'js/src/MuiPopoverTriggerId.jsx'. The trigger element acts as the anchor; the Popover opens on click and closes on clickaway.
Popover.triggerId(triggerId, ...)
triggerId |
HTML id of an existing DOM element that acts as the anchor/trigger for the Popover. |
... |
Named arguments forwarded as React props, plus children to render inside the component. |
Object with 'shiny.tag' class suitable for use in the UI of a Shiny app.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.